@@ -29,6 +29,8 @@ const (
 	JavaScript = "javascript"
 	RustBinary = "rustbinary"
 	Conan      = "conan"
+	Cocoapods  = "cocoapods"
+	Hex        = "hex"
 
 	// Config files
 	YAML           = "yaml"
@@ -41,6 +43,7 @@ const (
 	Helm           = "helm"
 	Rbac           = "rbac"
 	Cloud          = "cloud"
+	AzureARM       = "azure-arm"
 
 	// Licensing
 	License = "license"
@@ -69,4 +72,8 @@ const (
 	CargoLock = "Cargo.lock"
 
 	ConanLock = "conan.lock"
+
+	CocoaPodsLock = "Podfile.lock"
+
+	MixLock = "mix.lock"
 )
